==> hardwarelibrary-0.9.3.tar.gz: hardwarelibrary-0.9.3/hardwarelibrary/spectrometers/__init__.py <==
__all__ = ["oceaninsight"]

import os 
from pathlib import *

rootHardwareLibrary = Path(os.path.abspath(__file__)).parents[1]
stellarEncrypted = rootHardwareLibrary.joinpath('spectrometers/stellarnet.zip')
stellarDecrypted = rootHardwareLibrary.joinpath('spectrometers/stellarnet.py')

if os.path.exists(stellarEncrypted) and not os.path.exists(stellarDecrypted):
    print("The StellarNet software requires a password. Please contact StellarNet if you would like to use it.")
    print("Then, run `python3 -m hardwarelibrary --stellar` and enter the password when prompted.")
    print("Make sure you extract the files in the spectrometers/ directory of hardwarelibrary, where the zip file is.")

if not os.path.exists(stellarDecrypted):
    class StellarNet:
        def __init__(self):
            print("The StellarNet module must be licenced and decrypted by StellarNet. Please contact them for info.")
            print("If you have the password, run `python -m hardwarelibrary --stellar` and enter it at the prompt. Do not distribute.")
            print("Make sure you extract the files in the spectrometers/ directory of hardwarelibrary, where the zip file is.")
else:            
    from .stellarnet import StellarNet

from .oceaninsight import OISpectrometer, USB2000, USB4000
from .viewer import SpectraViewer

def any() -> OISpectrometer:
    return OISpectrometer.any()

def connectedUSBDevices(idProduct=None, serialNumber=None):
    return OISpectrometer.connectedUSBDevices(idProduct=idProduct, serialNumber=serialNumber)

def matchUniqueUSBDevice(idProduct=None, serialNumber=None):
    return OISpectrometer.matchUniqueUSBDevice(idProduct=idProduct, serialNumber=serialNumber)

==> hardwarelibrary-0.9.7.tar.gz: hardwarelibrary-0.9.7/hardwarelibrary/spectrometers/__init__.py <==
__all__ = ["oceaninsight"]

import os 
from pathlib import *

rootHardwareLibrary = Path(os.path.abspath(__file__)).parents[1]
stellarEncrypted = rootHardwareLibrary.joinpath('spectrometers/stellarnet.zip')
stellarDecrypted = rootHardwareLibrary.joinpath('spectrometers/stellarnet.py')

if not os.path.exists(stellarDecrypted):
    # We only warn the user if they try to use the StellarNet class
    class StellarNet:
        def __init__(self):
            print("The StellarNet module must be licenced and decrypted by StellarNet. Please contact them for info.")
            print("If you have the password, run `python -m hardwarelibrary --stellar` and enter it at the prompt. Do not distribute.")
            print("Make sure you extract the files in the spectrometers/ directory of hardwarelibrary, where the zip file is.")
else:            
    from .stellarnet import StellarNet

from .base import Spectrometer, getAllSubclasses
from .oceaninsight import OISpectrometer, USB2000, USB4000, USB2000Plus
from .viewer import SpectraViewer

def any() -> Spectrometer:
    return Spectrometer.any()

def displayAny():
    spectrometer = Spectrometer.any()
    if spectrometer is not None:
        spectrometer.initializeDevice()
        SpectraViewer(spectrometer).display()

def connectedUSBDevices(idProduct=None, serialNumber=None):
    return Spectrometer.connectedUSBDevices(idProduct=idProduct, serialNumber=serialNumber)

def matchUniqueUSBDevice(idProduct=None, serialNumber=None):
    return Spectrometer.matchUniqueUSBDevice(idProduct=idProduct, serialNumber=serialNumber)
